Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(95)

Unified Diff: runtime/vm/simulator_arm.h

Issue 12629004: Implement native call stub on ARM and native call redirection in ARM simulator. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/runtime_entry_arm.cc ('k') | runtime/vm/simulator_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/simulator_arm.h
===================================================================
--- runtime/vm/simulator_arm.h (revision 19698)
+++ runtime/vm/simulator_arm.h (working copy)
@@ -76,9 +76,12 @@
uword compare_value,
uword new_value);
- // Runtime call support.
- static uword RedirectExternalReference(uword function,
- uint32_t argument_count);
+ // Runtime and native call support.
+ enum CallKind {
+ kRuntimeCall,
+ kNativeCall
+ };
+ static uword RedirectExternalReference(uword function, CallKind call_kind);
void Longjmp(int32_t pc, int32_t sp, int32_t fp, const Instance& object);
« no previous file with comments | « runtime/vm/runtime_entry_arm.cc ('k') | runtime/vm/simulator_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698